@@ -122,7 +122,7 @@ function html_graph_area(&$graph_array, $no_graphs_message = '', $extra_url_args
 
 		foreach ($graph_array as $graph) {
 			if ($i == 0) {
-				print "<tr class='tableRow'>\n";
+				print "<tr class='tableRowGraph'>\n";
 			}
 
 			?>
@@ -237,7 +237,7 @@ function html_graph_thumbnail_area(&$graph_array, $no_graphs_message = '', $extr
 			}
 
 			if ($i == 0) {
-				print "<tr class='tableRow'>\n";
+				print "<tr class='tableRowGraph'>\n";
 				$start = false;
 			}
 
@@ -886,9 +886,9 @@ function draw_graph_items_list($item_list, $filename, $url_data, $disable_contro
 
 			/* alternating row color */
 			if ($use_custom_class == false) {
-				print "<tr class='tableRow'>\n";
+				print "<tr class='tableRowGraph'>\n";
 			} else {
-				print "<tr class='tableRow $customClass'>";
+				print "<tr class='tableRowGraph $customClass'>";
 			}
 
 			print '<td>';
@@ -1199,7 +1199,7 @@ function draw_actions_dropdown($actions_array, $delete_action = 1) {
 		}
 
 		$('tr[id^="line"]').not('.disabled_row').find('td').not('.checkbox').each(function(data) {
-			$(this).click(function(data) {
+			$(this).unbind().click(function(data) {
 				$(this).closest('tr').toggleClass('selected');
 				var checkbox = $(this).parent().find(':checkbox');
 				checkbox.prop('checked', !checkbox.is(':checked'));
@@ -1207,7 +1207,7 @@ function draw_actions_dropdown($actions_array, $delete_action = 1) {
 		});
 
 		$('tr[id^="line"]').find('input.checkbox').each(function(data) {
-			$(this).click(function(data) {
+			$(this).unbind().click(function(data) {
 				if (!$(this).closest('tr').hasClass('disabled_row')) {
 					$(this).closest('tr').toggleClass('selected');
 				}
@@ -1335,7 +1335,12 @@ function html_show_tabs_left() {
 		if ($config['poller_id'] > 1 && $config['connection'] != 'online') {
 			// Only show external links when online
 		} else {
-			$external_links = db_fetch_assoc('SELECT id, title FROM external_links WHERE style="TAB" AND enabled="on" ORDER BY sortorder');
+			$external_links = db_fetch_assoc('SELECT id, title
+				FROM external_links
+				WHERE style="TAB"
+				AND enabled="on"
+				ORDER BY sortorder');
+
 			if (sizeof($external_links)) {
 				foreach($external_links as $tab) {
 					if (is_realm_allowed($tab['id']+10000)) {
@@ -1649,9 +1654,9 @@ function html_host_filter($host_id = '-1', $call_back = 'applyFilter', $sql_wher
 		if ($host_id > 0) {
 			$hostname = db_fetch_cell_prepared("SELECT description FROM host WHERE id = ?", array($host_id));
 		} elseif ($host_id == 0) {
-			$hostname = 'None';
+			$hostname = __('None');
 		} else {
-			$hostname = 'Any';
+			$hostname = __('Any');
 		}
 
 		?>
