@@ -55,7 +55,7 @@ if (isset_request_var('mode') && in_array(get_nfilter_request_var('mode'), $mode
 
 	if (isset_request_var('header')) {
 		$option = 'header=false';
-	}else{
+	} else {
 		$option = '';
 	}
 
@@ -67,7 +67,7 @@ if (isset_request_var('mode') && in_array(get_nfilter_request_var('mode'), $mode
 
 			if ($_SESSION['sess_plugins_state'] != '-3') {
 				header('Location: plugins.php?state=5' . ($option != '' ? '&' . $option:''));
-			}else{
+			} else {
 				header('Location: plugins.php' . ($option != '' ? '?' . $option:''));
 			}
 			exit;
@@ -138,18 +138,20 @@ function plugins_load_temp_table() {
 
 	if (isset($_SESSION['plugin_temp_table'])) {
 		$table = $_SESSION['plugin_temp_table'];
-	}else{
+	} else {
 		$table = 'plugin_temp_table_' . rand();
 	}
 	$x = 0;
 	while ($x < 30) {
 		if (!plugins_temp_table_exists($table)) {
 			$_SESSION['plugin_temp_table'] = $table;
+
 			db_execute("CREATE TEMPORARY TABLE IF NOT EXISTS $table LIKE plugin_config");
 			db_execute("TRUNCATE $table");
 			db_execute("INSERT INTO $table SELECT * FROM plugin_config");
+
 			break;
-		}else{
+		} else {
 			$table = 'plugin_temp_table_' . rand();
 		}
 		$x++;
@@ -161,32 +163,39 @@ function plugins_load_temp_table() {
 		while (($file = readdir($dh)) !== false) {
 			if (is_dir("$path/$file") && file_exists("$path/$file/setup.php") && !in_array($file, $pluginslist) && !in_array($file, $plugins_integrated)) {
 				if (file_exists("$path/$file/INFO")) {
-					$info = parse_ini_file("$path/$file/INFO", true);
-					$cinfo[$file] = $info['info'];
+					$cinfo[$file] = plugin_load_info_file("$path/$file/INFO");
+
 					if (!isset($cinfo[$file]['author']))   $cinfo[$file]['author']   = __('Unknown');
 					if (!isset($cinfo[$file]['homepage'])) $cinfo[$file]['homepage'] = __('Not Stated');
 					if (isset($cinfo[$file]['webpage']))   $cinfo[$file]['homepage'] = $cinfo[$file]['webpage'];
 					if (!isset($cinfo[$file]['longname'])) $cinfo[$file]['longname'] = ucfirst($file);
+
 					$cinfo[$file]['status'] = 0;
 					$pluginslist[] = $file;
-					if (!isset($info['info']['compat']) || version_compare($config['cacti_version'], $info['info']['compat']) < 0) {
+
+					if (!isset($cinfo[$file]['compat']) || cacti_version_compare(CACTI_VERSION, $cinfo[$file]['compat'], '<')) {
 						$cinfo[$file]['status'] = -1;
 					}
 				} else {
 					$cinfo[$file] = array('name' => ucfirst($file), 'longname' => '', 'author' => '', 'homepage' => '', 'version' => '', 'compat' => '0.8');
 					$cinfo[$file]['status'] = -1;
 				}
+
 				$pluginslist[] = $file;
-				db_execute("REPLACE INTO $table (directory, name, status, author, webpage, version)
-						VALUES ('" .
-							$file . "', '" .
-							$cinfo[$file]['longname'] . "', '" .
-							$cinfo[$file]['status']   . "', '" .
-							$cinfo[$file]['author']   . "', '" .
-							$cinfo[$file]['homepage'] . "', '" .
-							$cinfo[$file]['version']  . "')");
+
+				db_execute_prepared("REPLACE INTO $table
+					(directory, name, status, author, webpage, version)
+					VALUES (?, ?, ?, ?, ?, ?)",
+					array(
+						$file,
+						$cinfo[$file]['longname'],
+						$cinfo[$file]['status'],
+						$cinfo[$file]['author'],
+						$cinfo[$file]['homepage'],
+						$cinfo[$file]['version']));
 			}
 		}
+
 		closedir($dh);
 	}
 
@@ -199,32 +208,32 @@ function update_show_current () {
 	/* ================= input validation and session storage ================= */
 	$filters = array(
 		'rows' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
 			),
 		'page' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'default' => '1'
 			),
 		'filter' => array(
-			'filter' => FILTER_CALLBACK, 
+			'filter' => FILTER_CALLBACK,
 			'pageset' => true,
-			'default' => '', 
+			'default' => '',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'sort_column' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'name', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'name',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'sort_direction' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'ASC', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'ASC',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'state' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-3'
 			)
@@ -238,7 +247,7 @@ function update_show_current () {
 	?>
 	<script type="text/javascript">
 	function applyFilter() {
-		strURL = 'plugins.php?filter='+$('#filter').val()+'&rows='+$('#rows').val()+'&page='+$('#page').val()+'&state='+$('#state').val()+'&header=false';
+		strURL = 'plugins.php?filter='+escape($('#filter').val())+'&rows='+$('#rows').val()+'&page='+$('#page').val()+'&state='+$('#state').val()+'&header=false';
 		loadPageNoHeader(strURL);
 	}
 
@@ -264,7 +273,7 @@ function update_show_current () {
 	</script>
 	<?php
 
-	html_start_box( __('Plugin Management (Cacti Version: %s)', $config['cacti_version']), '100%', '', '3', 'center', '');
+	html_start_box(__('Plugin Management'), '100%', '', '3', 'center', '');
 
 	?>
 	<tr class='even noprint'>
@@ -331,15 +340,15 @@ function update_show_current () {
 
 	if (get_request_var('state') > -3) {
 		if (get_request_var('state') == 5) {
-			$sql_where .= (strlen($sql_where) ? ' AND ':'WHERE ') . ' status IN(1,4)';
-		}else{
-			$sql_where .= (strlen($sql_where) ? ' AND ':'WHERE ') . ' status=' . get_request_var('state');
+			$sql_where .= ($sql_where != '' ? ' AND ':'WHERE ') . ' status IN(1,4)';
+		} else {
+			$sql_where .= ($sql_where != '' ? ' AND ':'WHERE ') . ' status=' . get_request_var('state');
 		}
 	}
 
 	if (get_request_var('rows') == '-1') {
 		$rows = read_config_option('num_rows_table');
-	}else{
+	} else {
 		$rows = get_request_var('rows');
 	}
 
@@ -387,22 +396,24 @@ function update_show_current () {
 		foreach ($plugins as $plugin) {
 			if ((isset($plugins[$j+1]) && $plugins[$j+1]['status'] < 0) || (!isset($plugins[$j+1]))) {
 				$last_plugin = true;
-			}else{
+			} else {
 				$last_plugin = false;
 			}
 			if ($plugin['status'] <= 0 || (get_request_var('sort_column') != 'id')) {
 				$load_ordering = false;
-			}else{
+			} else {
 				$load_ordering = true;
 			}
 
 			form_alternate_row('', true);
+
 			print format_plugin_row($plugin, $last_plugin, $load_ordering);
+
 			$i++;
 
 			$j++;
 		}
-	}else{
+	} else {
 		print '<tr><td><em>' . __('No Plugins Found') . '</em></td></tr>';
 	}
 
@@ -421,10 +432,17 @@ function format_plugin_row($plugin, $last_plugin, $include_ordering) {
 
 	$row = plugin_actions($plugin);
 
-	$row .= "<td><a href='" . htmlspecialchars($plugin['webpage']) . "' target='_blank'>" . (strlen(get_request_var('filter')) ? preg_replace('/(' . preg_quote(get_request_var('filter')) . ')/i', "<span class='filteredValue'>\\1</span>", ucfirst($plugin['directory'])) : ucfirst($plugin['directory'])) . '</a>' . (is_dir($config['base_path'] . '/plugins/' . $plugin['directory']) ? '':' (<span class="txtErrorText">' . __('ERROR: Directory Missing') . '</span>)') . '</td>';
+	$row .= "<td><a href='" . htmlspecialchars($plugin['webpage']) . "' target='_blank'>" . (get_request_var('filter') != '' ? preg_replace('/(' . preg_quote(get_request_var('filter')) . ')/i', "<span class='filteredValue'>\\1</span>", ucfirst($plugin['directory'])) : ucfirst($plugin['directory'])) . '</a>' . (is_dir($config['base_path'] . '/plugins/' . $plugin['directory']) ? '':' (<span class="txtErrorText">' . __('ERROR: Directory Missing') . '</span>)') . '</td>';
 
 	$row .= "<td class='nowrap'>" . filter_value($plugin['name'], get_request_var('filter')) . "</td>\n";
-	$row .= "<td class='nowrap'>" . $status_names[$plugin['status']] . "</td>\n";
+
+	if ($plugin['status'] == '-1') {
+		$status = plugin_is_compatible($plugin['directory']);
+		$row .= "<td class='nowrap'>" . __('Not Compatible, %s', $status['requires']) . "</td>\n";
+	}else{
+		$row .= "<td class='nowrap'>" . $status_names[$plugin['status']] . "</td>\n";
+	}
+
 	$row .= "<td class='nowrap'>" . $plugin['author'] . "</td>\n";
 	$row .= "<td class='right'>"  . $plugin['version'] . "</td>\n";
 
@@ -432,16 +450,16 @@ function format_plugin_row($plugin, $last_plugin, $include_ordering) {
 		$row .= "<td class='nowrap right'>";
 		if (!$first_plugin) {
 			$row .= "<a class='pic fa fa-caret-up moveArrow' href='" . htmlspecialchars($config['url_path'] . 'plugins.php?mode=moveup&id=' . $plugin['directory']) . "' title='" . __('Order Before Previous Plugin') . "'></a>";
-		}else{
+		} else {
 			$row .= '<span class="moveArrowNone"></span>';
 		}
 		if (!$last_plugin) {
 			$row .= "<a class='pic fa fa-caret-down moveArrow' href='" . htmlspecialchars($config['url_path'] . 'plugins.php?mode=movedown&id=' . $plugin['directory']) . "' title='" . __('Order After Next Plugin') . "'></a>";
-		}else{
+		} else {
 			$row .= '<span class="moveArrowNone"></span>';
 		}
 		$row .= "</td>\n";
-	}else{
+	} else {
 		$row .= "<td></td>\n";
 	}
 
